==> familia_0.1.tar.gz: familia/src/drawingarea.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <iostream>
#include <gtkmm.h>

#include "drawingarea.h"
#include "file/file.h"

extern file::File * document;

DrawingArea::DrawingArea() {

}

DrawingArea::~DrawingArea() {
}

bool DrawingArea::on_draw(const Cairo::RefPtr<Cairo::Context>& cr) {
  Gtk::Allocation allocation = get_allocation();
  const int width = allocation.get_width();
  const int height = allocation.get_height();

  if(document == NULL) {
    return false;
  }

  cr->rectangle(0,0,width, height);
  cr->set_source_rgba(1, 1, 1, 1);
  /*
  cr->arc(width / 2.0, height / 2.0,
             MIN (width, height) / 2.0,
             0, 2 * G_PI);
  */
  cr->fill();
  /*

  images.male = Gdk::Pixbuf::create_from_file("f.png");
  Gdk::Cairo::set_source_pixbuf(cr, images.male, 0, 0);
  cr->rectangle(0, 0, images.male->get_width()-20, images.male->get_height()-20);
  cr->fill();
*/
  
  std::cout << "DrawingArea::on_draw" << std::endl;
  std::cout << "Number of individuals: " << document->individuals.size() << std::endl;

  _Individuals::iterator it;
  for(it = document->individuals.begin(); it != document->individuals.end(); it++) {
    cout << "Drawing: " << it->first << endl;
    it->second.draw(cr);
  }

  std::cout << "Drawed!" << std::endl;

  return true;
}

==> familia_0.1.2.tar.gz: familia/src/drawingarea.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <iostream>
#include <gtkmm.h>

#include "drawingarea.h"
#include "file/file.h"
#include "fileloader.h"

DrawingArea::DrawingArea() {

}

DrawingArea::~DrawingArea() {
}

bool DrawingArea::on_draw(const Cairo::RefPtr<Cairo::Context>& cr) {
  Gtk::Allocation allocation = get_allocation();
  const int width = allocation.get_width();
  const int height = allocation.get_height();

  cr->rectangle(0,0,width, height);
  cr->set_source_rgba(1, 1, 1, 1);
  /*
  cr->arc(width / 2.0, height / 2.0,
             MIN (width, height) / 2.0,
             0, 2 * G_PI);
  */
  cr->fill();
  /*

  images.male = Gdk::Pixbuf::create_from_file("f.png");
  Gdk::Cairo::set_source_pixbuf(cr, images.male, 0, 0);
  cr->rectangle(0, 0, images.male->get_width()-20, images.male->get_height()-20);
  cr->fill();
*/
  
  std::cout << "DrawingArea::on_draw" << std::endl;
  std::cout << "File index: " << index << std::endl;
  if(index > FileLoader::instance()->files.size()) return false;

  std::cout << "Number of individuals: " << FileLoader::instance()->files.at(index)->individuals.size() << std::endl;
  
  _Individuals::iterator it;
  for(it = (FileLoader::instance()->files.at(index)->individuals.begin()); it != (FileLoader::instance()->files.at(index)->individuals.end()); it++) {
    cout << "Drawing: " << it->name().getFirst() << endl;
    it->draw(cr);
  }
  
  std::cout << "Drawed!" << std::endl;

  return true;
}
